@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2009--2012 Marc Hohl <marc@hohlart.de>
+;;;; Copyright (C) 2009--2020 Marc Hohl <marc@hohlart.de>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; helper functions for staff and layout properties
 
-(define (calc-blot thickness extent grob)
+(define (bar-line::calc-blot thickness extent grob)
   "Calculate the blot diameter by taking @code{'rounded}
 and the dimensions of the extent into account."
   (let* ((rounded (ly:grob-property grob 'rounded #f))
@@ -39,9 +39,18 @@ and the dimensions of the extent into account."
                            ((< height blot-diameter) height)
                            (else blot-diameter)))
                    0)))
-
     blot))
 
+(define-public (bar-line::draw-filled-box x-ext y-ext thickness extent grob)
+  "Return a straight bar-line created by @code{ly:round-filled-box} looking at
+@var{x-ext}, @var{y-ext}, @var{thickness}.  The blot is calculated by
+@code{bar-line::calc-blot}, which needs @var{extent} and @var{grob}.
+@var{y-ext} is not necessarily of same value as @var{extent}."
+  (ly:round-filled-box
+   x-ext
+   y-ext
+   (bar-line::calc-blot thickness extent grob)))
+
 (define (get-span-glyph bar-glyph)
   "Get the corresponding span glyph from the @code{span-glyph-bar-alist}.
 Pad the string with @code{annotation-char}s to the length of the
@@ -169,29 +178,6 @@ annotation char from string @var{str}."
            (_ "Replacement '~a' is allowed in the last argument of a bar line definition only.")
            str))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; functions used by external routines
-
-(define-public (span-bar::notify-grobs-of-my-existence grob)
-  "Set the @code{'has-span-bar} property for all elements of Grob @var{grob}."
-  (let* ((elts (ly:grob-array->list (ly:grob-object grob 'elements)))
-         (sorted-elts (sort elts ly:grob-vertical<?))
-         (last-pos (1- (length sorted-elts)))
-         (idx 0))
-
-    (for-each (lambda (g)
-                (ly:grob-set-property!
-                 g
-                 'has-span-bar
-                 (cons (if (eq? idx last-pos)
-                           #f
-                           grob)
-                       (if (zero? idx)
-                           #f
-                           grob)))
-                (set! idx (1+ idx)))
-              sorted-elts)))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Line break decisions.
 
@@ -250,35 +236,38 @@ is not used within the routine."
   (let* ((line-thickness (layout-line-thickness grob))
          (thickness (* (ly:grob-property grob 'hair-thickness 1)
                        line-thickness))
-         (blot (calc-blot thickness extent grob))
          (extent (bar-line::widen-bar-extent-on-span grob extent)))
-
-    (ly:round-filled-box (cons 0 thickness)
-                         extent
-                         blot)))
+    (bar-line::draw-filled-box
+     (cons 0 thickness)
+     extent
+     thickness
+     extent
+     grob)))
 
 (define (make-thick-bar-line grob extent)
   "Draw a thick bar line."
   (let* ((line-thickness (layout-line-thickness grob))
          (thickness (* (ly:grob-property grob 'thick-thickness 1)
                        line-thickness))
-         (blot (calc-blot thickness extent grob))
          (extent (bar-line::widen-bar-extent-on-span grob extent)))
-
-    (ly:round-filled-box (cons 0 thickness)
-                         extent
-                         blot)))
+    (bar-line::draw-filled-box
+     (cons 0 thickness)
+     extent
+     thickness
+     extent
+     grob)))
 
 (define (make-tick-bar-line grob extent)
   "Draw a tick bar line."
   (let* ((half-staff (* 1/2 (ly:staff-symbol-staff-space grob)))
          (staff-line-thickness (ly:staff-symbol-line-thickness grob))
-         (height (interval-end extent))
-         (blot (calc-blot staff-line-thickness extent grob)))
-
-    (ly:round-filled-box (cons 0 staff-line-thickness)
-                         (cons (- height half-staff) (+ height half-staff))
-                         blot)))
+         (height (interval-end extent)))
+    (bar-line::draw-filled-box
+     (cons 0 staff-line-thickness)
+     (cons (- height half-staff) (+ height half-staff))
+     staff-line-thickness
+     extent
+     grob)))
 
 (define (make-colon-bar-line grob extent)
   "Draw repeat dots."
@@ -440,14 +429,14 @@ is not used within the routine."
 the segno sign is drawn over the double bar line; otherwise, it
 draws the span bar variant, i.e. without the segno sign."
   (let* ((line-thickness (layout-line-thickness grob))
-         (thinkern (* (ly:grob-property grob 'thin-kern 1) line-thickness))
+         (segno-kern (* (ly:grob-property grob 'segno-kern 1) line-thickness))
          (thin-stil (make-simple-bar-line grob extent))
          (double-line-stil (ly:stencil-combine-at-edge
                             thin-stil
                             X
                             LEFT
                             thin-stil
-                            thinkern))
+                            segno-kern))
          (segno (ly:font-get-glyph (ly:grob-default-font grob)
                                    "scripts.varsegno"))
          (stencil (ly:stencil-add
@@ -459,7 +448,7 @@ draws the span bar variant, i.e. without the segno sign."
                         (cons 0 0)))
                    (ly:stencil-translate-axis
                     double-line-stil
-                    (* 1/2 thinkern)
+                    (* 1/2 segno-kern)
                     X))))
 
     stencil))
@@ -467,11 +456,11 @@ draws the span bar variant, i.e. without the segno sign."
 (define (make-kievan-bar-line grob extent)
   "Draw a kievan bar line."
   (let* ((font (ly:grob-default-font grob))
-         (stencil (stencil-whiteout
+         (stencil (stencil-whiteout-box
                    (ly:font-get-glyph font "scripts.barline.kievan"))))
 
     ;; the kievan bar line has no staff lines underneath,
-    ;; so we whiteout them and move the grob to a higher layer
+    ;; so we whiteout-box them and move the grob to a higher layer
     (ly:grob-set-property! grob 'layer 1)
     stencil))
 
@@ -500,9 +489,9 @@ opening bracket will be drawn, for @code{RIGHT} we get the closing bracket."
                                               (interval-start extent)
                                               Y))))
 
-    (if (eq? dir LEFT)
+    (if (eqv? dir LEFT)
         stencil
-        (ly:stencil-scale stencil -1 1))))
+        (flip-stencil X stencil))))
 
 (define ((make-spacer-bar-line glyph) grob extent)
   "Draw an invisible bar line which has the same dimensions as the one
@@ -557,7 +546,7 @@ drawn by the procedure associated with glyph @var{glyph}."
 (define-public (bar-line::widen-bar-extent-on-span grob extent)
   "Widens the bar line @var{extent} towards span bars adjacent to grob @var{grob}."
   (let ((staff-symbol (get-staff-symbol grob))
-        (has-span-bar (ly:grob-property grob 'has-span-bar #f)))
+        (has-span-bar (ly:grob-object grob 'has-span-bar)))
 
     (if (and (ly:grob? staff-symbol)
              (pair? has-span-bar))
@@ -667,8 +656,10 @@ the correct placement of bar numbers etc."
 
     (and (> (interval-length x-extent) 0)
          (if (or (= (length bar-glyph-list) 1)
-                 (string=? bar-glyph span-glyph)
-                 (string=? span-glyph ""))
+                 ;; 'span-glyph' may be #f, thus use equal? and not string=? for
+                 ;; comparing equality
+                 (equal? bar-glyph span-glyph)
+                 (equal? span-glyph ""))
              ;; We use the x-extent of the stencil if either
              ;; - we have a single bar-glyph
              ;; - bar-glyph and span-glyph are identical
@@ -1049,7 +1040,7 @@ of the volta brackets relative to the bar lines."
 (define-bar-line ":|." ":|." #f " |.")
 (define-bar-line ".|:" "|" ".|:" ".|")
 (define-bar-line "[|:" "|" "[|:" " |")
-(define-bar-line ":|]" ":|]" #f " |")
+(define-bar-line ":|]" ":|]" #f " | ")
 (define-bar-line ":|][|:" ":|]" "[|:" " |  |")
 (define-bar-line ".|:-||" "||" ".|:" ".|")
 
